import {
  CognitoIdentityClient,
  CognitoIdentityClientConfig,
} from "./loadCognitoIdentity";
import { Logins } from "./Logins";
export interface CognitoProviderParameters {
  client?: CognitoIdentityClient;
  clientConfig?: CognitoIdentityClientConfig;
  customRoleArn?: string;
  logins?: Logins;
}
