import { CognitoIdentityClient, GetCredentialsForIdentityCommand, GetIdCommand, } from "@aws-sdk/client-cognito-identity";
export { CognitoIdentityClient, GetCredentialsForIdentityCommand, GetIdCommand };
