import { Storage } from "./Storage";
/**
 * @internal
 */
export declare class InMemoryStorage implements Storage {
    private store;
    constructor(store?: Record<string, string>);
    getItem(key: string): string | null;
    removeItem(key: string): void;
    setItem(key: string, value: string): void;
}
