import {
  CognitoIdentityClient,
  GetCredentialsForIdentityCommand,
  GetIdCommand,
} from "@aws-sdk/client-cognito-identity";
export {
  CognitoIdentityClient,
  GetCredentialsForIdentityCommand,
  GetIdCommand,
};
export { CognitoIdentityClientConfig } from "@aws-sdk/client-cognito-identity";
